<?php

namespace Litecms\Power\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Power\Models\Power;

class PowerPolicy
{

    /**
     * Determine if the given user can view the power.
     *
     * @param UserPolicy $user
     * @param Power $power
     *
     * @return bool
     */
    public function view(UserPolicy $user, Power $power)
    {
        if ($user->canDo('power.power.view') && $user->isAdmin()) {
            return true;
        }

        return $power->user_id == user_id() && $power->user_type == user_type();
    }

    /**
     * Determine if the given user can create a power.
     *
     * @param UserPolicy $user
     * @param Power $power
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('power.power.create');
    }

    /**
     * Determine if the given user can update the given power.
     *
     * @param UserPolicy $user
     * @param Power $power
     *
     * @return bool
     */
    public function update(UserPolicy $user, Power $power)
    {
        if ($user->canDo('power.power.edit') && $user->isAdmin()) {
            return true;
        }

        return $power->user_id == user_id() && $power->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given power.
     *
     * @param UserPolicy $user
     * @param Power $power
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Power $power)
    {
        return $power->user_id == user_id() && $power->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given power.
     *
     * @param UserPolicy $user
     * @param Power $power
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Power $power)
    {
        if ($user->canDo('power.power.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given power.
     *
     * @param UserPolicy $user
     * @param Power $power
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Power $power)
    {
        if ($user->canDo('power.power.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
